/*

This file is part of jHaushalt.

jHaushalt is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

jHaushalt is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with jHaushalt; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

(C)opyright 2002-2006 Dr. Lars H. Hahn

*/

package haushalt.gui.dialoge;
import haushalt.daten.Datenbasis;
import haushalt.auswertung.DlgContainerAuswertung;
import haushalt.gui.Haushalt;
import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Image;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.net.URL;
import java.net.URLClassLoader;
import java.util.Properties;

import javax.swing.Box;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;


/**
 * Dialog mit dem die Programm-Information angezeigt werden.
 * @author Dr. Lars H. Hahn
 * @version 2.1/2006.01.27
 */

/*
 * 2006.01.26: Ausgabe der verschienden Versionstnde
 * 2006.01.27: Cache-Statistik hinzugefgt
 */

public class DlgInfo extends JDialog {

  private static final long serialVersionUID = 1L;
  private final JPanel southPane = new JPanel();
  protected final JTextArea textArea = new JTextArea(10, 30);
  private final JButton buttonGC = new JButton("GC starten");
  private final JButton buttonAbbruch = new JButton("Schlieen");

  public DlgInfo(JFrame frame) {
    super(frame, "Programm-Info", true);
    textArea.setEditable(true);
    textArea.selectAll();
    textArea.cut();
    textArea.setEditable(false);
    textArea.append(Haushalt.COPYRIGHT+"\n\n");
    textArea.append("Fr jHaushalt besteht KEINERLEI GARANTIE.\n");
    textArea.append("jHaushalt ist freie Software, die Sie unter\n");
    textArea.append("bestimmten Bedingungen weitergeben drfen.\n\n");

    textArea.append("Version GUI: "+Haushalt.VERSION+"\n");
    textArea.append("Version Datenbasis: "+Datenbasis.VERSION_DATENBASIS+"\n");
    textArea.append("Version Auswertungen: "+DlgContainerAuswertung.VERSION_AUSWERTUNG+"\n");
    textArea.append("Auswertungscache (Hit/Miss): "+
        Datenbasis.cacheHit+"/"+Datenbasis.cacheMiss+" = "+
        100.0*Datenbasis.cacheHit/(Datenbasis.cacheHit+Datenbasis.cacheMiss)+"\n");
    Properties prop = System.getProperties();
    textArea.append("Betriebssystem: "+prop.getProperty("os.name")+"\n");
    textArea.append("Architektur: "+prop.getProperty("os.arch")+"\n");
    textArea.append("Java-VM Version: "+prop.getProperty("java.vm.version")+"\n");
    textArea.append("Freier Speicher: "+Runtime.getRuntime().freeMemory()+"\n");
    textArea.append("Gesamter Speicher: "+Runtime.getRuntime().totalMemory());
    textArea.setAlignmentX(LEFT_ALIGNMENT);

    buttonGC.addActionListener(new ActionListener(){
      public void actionPerformed(ActionEvent e) {
        System.gc();
        textArea.append("\nFreier Speicher: "+Runtime.getRuntime().freeMemory());
      }
    });
    buttonAbbruch.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        setVisible(false);
      }
    });
    getRootPane().setDefaultButton(buttonAbbruch);

		URLClassLoader urlLoader = (URLClassLoader)getClass().getClassLoader();
		URL fileLoc = urlLoader.findResource("res/jhh-image.png");
		Image image = Toolkit.getDefaultToolkit().createImage(fileLoc);
    Container contentPane = getContentPane();
    contentPane.add(new JLabel(new ImageIcon(image)), BorderLayout.WEST);
    contentPane.add(Box.createRigidArea(new Dimension(5,0)), BorderLayout.CENTER);
    contentPane.add(new JScrollPane(textArea), BorderLayout.EAST);
    contentPane.add(southPane, BorderLayout.SOUTH);
    southPane.add(buttonGC);
    southPane.add(buttonAbbruch);
  }
}
